@@ -25,14 +25,18 @@ CELERY_IGNORE_RESULT = True
 # 设置结果的保存时间
 CELERY_TASK_RESULT_EXPIRES = 24 * 3600
 
-CELERYD_MAX_TASKS_PER_CHILD = 100  # 每个worker执行了多少任务就会死掉，防止OOM
+# worker执行任务以后不会自动释放内存，需要设置每个进程执行固定次数后销毁
+CELERYD_MAX_TASKS_PER_CHILD = 10  # 每个worker执行了多少任务就会死掉，防止OOM
 
+# 队列路由规则：routing_key、queue的名字规则
 CELERY_QUEUES = (
+    Queue("default", Exchange("default", type='direct'), routing_key="default"),
     Queue("celery", Exchange("celery", type='direct'), routing_key="celery"),
     Queue("for_task_A", Exchange("for_task_A", type='direct'), routing_key="for_task_A"),
     Queue("for_task_B", Exchange("for_task_B", type='direct'), routing_key="for_task_B")
 )
 
+# 批量设置文件内的所有事件的队列名称
 CELERY_ROUTES = {
     'tasks.task_x': {"queue": "celery"},
     'tasks.taskA': {"queue": "for_task_A", "routing_key": "for_task_A"},
