@@ -88,28 +88,63 @@ class PyMysqlPooledDB(object):
         [self.__dict_datetime_obj_to_str(row_dict) for row_dict in result]
         return result
 
-    def insert(self, table, insert_data):
+    def insert(self, table, insert_data, many=False, new=True):
         """
         from pymysql.converters import escape_string
         content: escape_string(content)
         :param table:
-        :param insert_data  type:[{"field1": 1},{"field2": 2}]:
+        :param insert_data  type:[{"field1": 1},{"field2": 2}]
+        :param many  type: true 批量写入（last_insert_id()得到的值不准确）
+                           false 逐条写入（last_insert_id()得到的值为准确值,需要获得最新的id值，请使用逐条写入）
+                           last_insert_id(): 当前连接，整个数据库内，上一次insert事务提交后，生成的最后一个自增key的值,
+                           若连接断开，则值为0
+        :param new  type: 若id为自增键时，True 返回最新记录，False返回影响条数
         :return:count 1 影响的行数
         """
         count = 0
-        insert_data = insert_data if isinstance(insert_data, (list, tuple)) else [insert_data]
+        last_insert_ids = []
+        insert_datas = insert_data if isinstance(insert_data, (list, tuple)) else [insert_data]
         try:
-            columns = ','.join(list(insert_data[0].keys()))
-            data_list = [tuple(data.values()) for data in insert_data]
-            values = len(data_list[0]) * "%s,"
-            sql = "insert into " + table + " (" + columns + ") values (" + values[:-1] + ")"
-            count = self.execute(sql, data_list)
+            columns = ','.join(list(insert_datas[0].keys()))
+            params = [tuple(data.values()) for data in insert_datas]
+            values = (len(params[0]) * "%s,").rstrip(",")
+            sql = "insert into " + table + " (" + columns + ") values (" + values + ")"
+            if many:
+                count = self.cursor.executemany(sql, params)
+            else:
+                for item in params:
+                    count += self.cursor.execute(sql, item)
+                    if new:
+                        self.cursor.execute("select last_insert_id() as id")
+                        result = self.cursor.fetchone()
+                        if result:
+                            last_insert_ids.append(result["id"])
             self.__commit()
         except Exception as e:
-            logging.error(e)
             self.rollback()
-        finally:
-            return count
+            raise e
+        else:
+            if new:
+                if not isinstance(insert_data, (list, tuple)):
+                    sql = f'select * from {table} where id = %s'
+                    return self.select_one(sql, last_insert_ids[0])
+                else:
+                    sql = f'select * from {table} where id in %s'
+                    return self.select_all(sql, [tuple(last_insert_ids)])
+            else:
+                return count
+
+    def inserts(self, table, insert_data, new=False):
+        """
+        批量写入
+        new： True 返回新写入的数据列表（写入为逐条写入，非原子性） False不返回最新数据，只返回影调条数（原子写入）
+        """
+        if new:
+            datas = self.insert(table, insert_data, many=False, new=True)
+            return datas
+        else:
+            counts = self.insert(table, insert_data, many=True, new=False)
+            return counts
 
     def update(self, sql, params=None):
         """
@@ -123,7 +158,6 @@ class PyMysqlPooledDB(object):
             self.update('update demo set name=2 where name=%s order by id limit 1', (22,))
         """
         count = self.__execute(sql, params)
-        self.__commit()
         return count
 
     def delete(self, sql, params=None):
@@ -138,13 +172,12 @@ class PyMysqlPooledDB(object):
             self.delete('delete from demo where name=%s order by id limit 1', (22,))
         """
         count = self.__execute(sql, params)
-        self.__commit()
         return count
 
     def query_sql(self, sql, params=None):
         """
-        灵活使用，sql不要拼接或采用format()，请用传参方式，防止注入
-        常用：insert、delete、update
+        查询数据
+        sql不要拼接或采用format()，请用传参方式，防止注入
 
         If args is a list or tuple, %s can be used as a placeholder in the query.
         If args is a dict, %(name)s can be used as a placeholder in the query.
@@ -159,36 +192,36 @@ class PyMysqlPooledDB(object):
 
         """
         try:
-            self.cursor.execute(sql, params)
+            self.execute(sql, params)
         except Exception as e:
             logging.error(sql)
-            logging.error(e)
+            raise e
         else:
             result = self.cursor.fetchall()
             return result or []
 
     def execute(self, sql, params=None):
         """
+        提交数据
         原生执行，sql不要拼接.format，用传参方式，防止注入
         常用于：insert、delete、update
         :param sql:
-        :param param:
+        :param param: [1, 2]、[(1, 2), (3, 4)]
         :return:
         """
         count = 0
         try:
             count = self.__execute(sql, params)
-            self.__commit()
         except Exception as e:
             logging.error(sql)
-            logging.error(e)
             self.rollback()
-        finally:
+            raise e
+        else:
             return count
 
     def begin(self):
         """开启事务: 先关闭自动提交模式"""
-        self.conn.autocommit(0)
+        self.conn.begin()
 
     def end(self, option='commit'):
         """
@@ -197,13 +230,12 @@ class PyMysqlPooledDB(object):
         还原事务提交模式
         """
         if option == 'commit':
-            self.conn.commit()
+            self.commit()
         else:
-            self.conn.rollback()
-        self.conn.autocommit(self.autocommit_mode)
+            self.rollback()
 
     def commit(self):
-        """直接提交事务：无当前事务提交模式无关"""
+        """手动提交事务"""
         self.conn.commit()
 
     def rollback(self):
@@ -218,23 +250,31 @@ class PyMysqlPooledDB(object):
             self.cursor.close()
             self.conn.close()
         except Exception as e:
-            logging.error(e)
+            raise e
 
+    def parse_set_condition_value(self, **params):
+        sql_columns = ""
+        for k in params.keys():
+            sql_columns += k + "=%s,"
+        sql_columns = sql_columns.rstrip(",")
+        sql_values = params.values()
+        return sql_columns, list(sql_values)
 
     def __commit(self):
         """按当前autocommit配置，决定是否提交事务"""
         if self.autocommit_mode:
-            self.conn.commit()
+            return self.conn.commit()
         else:
             pass    # 需手动调用self.commit()提交
 
     def __execute(self, sql, params=None):
         count = self.cursor.execute(sql, params)
+        self.__commit()
         return count
 
     @staticmethod
     def __dict_datetime_obj_to_str(result_dict):
-        """把字典里面的datatime对象转成字符串，使json转换不出错"""
+        """把字典里面的datatime对象转成字符串"""
         if result_dict:
             result_replace = {k: v.__str__() for k, v in result_dict.items() if isinstance(v, datetime.datetime)}
             result_dict.update(result_replace)
