@@ -10,6 +10,7 @@ from lcyframe.libs import errors
 from lcyframe.libs.JWT import JwtToken
 import urllib
 
+
 def authorize(method):
     @wraps(method)
     def check_token(self, *args, **kwargs):
@@ -53,7 +54,9 @@ def params(permission_bit=0):
         def has_role(self, *args, **kwargs):
             self.params = get_params(self)
             if self.app_config.get("logging_config", {}).get("level", "debug") == "debug":
-                logging.debug(self.params)
+                logging.debug("请求参数: " + (utils.to_json(utils.check2json(utils.pparams(self.request, self.params)))
+                                          if hasattr(self, "params") else str(
+                    utils.pparams(self.request, self.request.arguments) or {})))
 
             uid = self.request.headers.get("uid", None) or 0
             if type(uid) != int and uid.isdigit():
@@ -77,18 +80,27 @@ def params(permission_bit=0):
 
 
 def get_params(self, fill_default=True):
-
+    """
+    www-form、body_from: Body 类型 : application/x-www-form-urlencoded
+    form-data：Body 类型 : multipart/form-data
+    body-json: Body 类型 : application/json
+    raw:Body 类型 : text/plain
+    """
     p = {}
     method = self.request.method.lower()
-
-    if not self.request.arguments:
+    arguments = self.request.arguments
+    body_arguments = self.request.arguments
+    body_json_arguments = {}
+    try:
+        body_json_arguments = {k: v for k, v in
+                               [item.split("=") for item in self.request.body.decode().split("&")]}
+    except Exception as e:
         try:
-            body_arguments = {k: v for k, v in
-                              [item.split("=") for item in self.request.body.decode().split("&")]}
+            body_json_arguments = utils.to_python(self.request.body)
         except Exception as e:
-            body_arguments = {}
-    else:
-        body_arguments = self.request.arguments
+            body_json_arguments = {}
+
+    self.request.body_json_arguments = body_json_arguments
 
     if not self.request.files:
         files = {}
@@ -101,7 +113,7 @@ def get_params(self, fill_default=True):
     else:
         # from tornado.routing import RuleRouter, PathMatches, _unquote_or_none
         for route in self.application.handlers:
-            match = route.regex.match(self.request.path)        # ref: routing.PathMatches.match
+            match = route.regex.match(self.request.path)  # ref: routing.PathMatches.match
             if match is not None:
                 pattern1 = route.regex.pattern
                 pattern2 = route.regex.pattern.rstrip("$")
@@ -132,18 +144,18 @@ def get_params(self, fill_default=True):
             regex = item.get("regex")
             allow = item.get("allow", []) or item.get("allowed", [])
             message = item.get("message", "")
+            if _type in ["files", "file"]:
+                item.setdefault("in", "form-data")
 
+            # 不强制参数所在位置
             if item.get("in") is None:
-                if self.request.arguments:
+                if params_name in arguments:
                     if item["type"] == "list":
                         # 参数为数组
                         params_vaule = self.get_arguments(params_name) or None
                     else:
                         params_vaule = self.get_argument(params_name, None, strip=True)
-                else:
-                    if not body_arguments:
-                        raise errors.ErrorArgumentValue
-
+                elif params_name in body_arguments:
                     params_vaule = body_arguments.get(params_name)
                     try:
                         if params_vaule:
@@ -153,6 +165,12 @@ def get_params(self, fill_default=True):
                         e = errors.ErrorArgumentValue
                         e.message = msg
                         raise e
+                elif params_name in body_json_arguments:
+                    params_vaule = body_json_arguments.get(params_name)
+                else:
+                    params_vaule = None
+
+            # 强制指定参数位置
             else:
                 _in = item.get("in", "query")
                 if _type in ["file", "files"]:
@@ -172,29 +190,6 @@ def get_params(self, fill_default=True):
                     else:
                         params_vaule = self.get_argument(params_name, None, strip=True)
 
-                elif _in in ["body-json"]:
-                    if self.request.arguments:
-                        if item["type"] == "list":
-                            # 参数为数组
-                            params_vaule = self.get_arguments(params_name) or None
-                        else:
-                            params_vaule = self.get_argument(params_name, None, strip=True)
-                    else:
-                        if self.request.body:
-                            body_arguments = {k: v for k, v in [item.split("=") for item in self.request.body.decode().split("&")]}
-                        else:
-                            body_arguments = {}
-
-                        params_vaule = body_arguments.get(params_name)
-                        try:
-                            if params_vaule:
-                                params_vaule = urllib.parse.unquote(params_vaule)
-                        except Exception as e:
-                            msg = "Argument '%s' Value '%s' Error" % (params_name, params_vaule)
-                            e = errors.ErrorArgumentValue
-                            e.message = msg
-                            raise e
-
                 elif _in in ["form-data"]:
                     if item["type"] == "list":
                         # 参数为数组
@@ -208,6 +203,17 @@ def get_params(self, fill_default=True):
                     else:
                         params_vaule = self.get_argument(params_name, None, strip=True)
 
+                elif _in in ["body-json", "raw"]:
+                    params_vaule = body_json_arguments.get(params_name)
+                    try:
+                        if params_vaule:
+                            params_vaule = urllib.parse.unquote(params_vaule)
+                    except Exception as e:
+                        msg = "Argument '%s' Value '%s' Error" % (params_name, params_vaule)
+                        e = errors.ErrorArgumentValue
+                        e.message = msg
+                        raise e
+
                 elif _in in ["binary"]:
                     msg = "参数：'%s'，不再支持将参数位置设置为binary方式" % params_name
                     e = errors.ErrorArgumentValue
@@ -218,7 +224,7 @@ def get_params(self, fill_default=True):
 
                 else:
                     # raise errors.ErrorArgumentType
-                    msg = "Missing Argument '%s'. must in [query, form-data, www-form, file]." % params_name
+                    msg = "Missing Argument '%s'. must in [query, form-data, www-form, body-form, body-json, file]." % params_name
                     e = errors.ErrorMissingArgument
                     e.message = msg
                     raise e
@@ -239,7 +245,6 @@ def get_params(self, fill_default=True):
                     params_vaule = item.get("default")
                 else:
                     continue
-
             else:
                 # 按照默认值的类型 转换参数
                 try:
@@ -312,6 +317,8 @@ def recursion(response, definition, force_return=False):
             # raise TypeError("Response data type != .yml response definition!")
 
     if type(definition) is dict:
+        if definition == {}:
+            return response
         for k, v in definition.items():
             k = str(k)
             if k not in response:
