@@ -42,13 +42,14 @@ def get_docs_agree():
 
 **请求方式：本框架规定了所有请求参数所配置的方式以及用途：**
 
-|参数位置|Content-Type|编码方式|举个例子|说明|
-|---|---|---|---|---|
-|path|--|--|/url/{user}/{uid}|拼接在url内|
-|query|--|--|/url/user?uid=10|拼接在?后|
-|body|application/x-www-form-urlencoded|x-www-form-urlencoded|'uid=100&sex=1'|表单提交，推荐|
-|body|application/json|x-www-form-urlencoded|'uid=100&sex=1'|json提交|
-|body|multipart/form-data|form-data|{"file": open("../demo.jpg")}|上传文件|
+|参数位置|Content-Type|举个例子|说明|
+|---|---|---|---|
+|path|--|/url/{user}/{uid}|拼接在url内|
+|query|--|/url/user?uid=10|拼接在?后|
+|body|application/x-www-form-urlencoded|{"uid": 100, "sex": 1}|表单提交，推荐|
+|body|multipart/form-data|{"file": open("demo.jpg"), "header": open("header.jpg")}|上传文件|
+|body|application/json|'uid=100&sex=1'或'{"uid":100,"sex:1"}'|json提交|
+|body|text/plain|'uid=100&sex=1'或'{"uid":100,"sex:1"}'|--|
 
 > 1、path：参数被设置在请求url内；如"/url/xxx/yyy"。注意，使用该模式，框架不会自动收集参数，即self.params永远为空
 
@@ -172,6 +173,13 @@ seq = md5(salt + "nickname=阿刘&age=111&timestamp=1473761433")
 **测试环境：**
 > 1、api：http://192.168.2.140:6700  
 > 2、docs文档：http://192.168.2.140:6779
+
+### 1.7、免责声明
+本框架仅能在取得足够合法授权的企业安全建设中使用，在使用本过程中，您应确保自己所有行为符合当地的法律法规。 
+如您在使用本工具的过程中存在任何非法行为，您将自行承担所有后果，开发者不承担任何法律及连带责任。 
+除非您已充分阅读、完全理解并接受本协议所有条款，否则，请您不要安装并使用本框架。
+您的使用行为或者您以其他任何明示或者默示方式表示接受本协议的，即视为您已阅读并同意本协议的约束。
+
 """
     return auto_str
 
